.. image:: https://img.shields.io/pypi/v/nerodia.svg
    :target: https://pypi.python.org/pypi/nerodia

.. image:: https://img.shields.io/pypi/pyversions/nerodia.svg
    :target: https://pypi.python.org/pypi/nerodia

.. image:: https://travis-ci.org/watir/nerodia.svg?branch=master
    :target: https://travis-ci.org/watir/nerodia

.. image:: https://ci.appveyor.com/api/projects/status/7go9s2tmp2av08sa?svg=true
    :target: https://ci.appveyor.com/project/joshmgrant/nerodia/branch/master


-----

Introduction
============
Nerodia is a Python port of the Watir ruby gem. https://github.com/watir/watir

Supported Python Versions
=========================

* Python 2.7
* Python 3.4+

Installing
==========

If you have `pip <https://pip.pypa.io/>`_ on your system, you can simply install or upgrade::

    pip install -U nerodia

Alternately, you can download the source distribution from `PyPI <http://pypi.python.org/pypi/nerodia>`_ (e.g. nerodia-1.0.0.tar.gz), unarchive it, and run::

    python setup.py install

Documentation
=================

Documentation is `located on readthedocs <http://nerodia.readthedocs.io/en/latest/>`_.

Support
=======

Send a question to the `Nerodia-General <https://groups.google.com/forum/#!forum/nerodia-general>`_ mailing list on Google Groups. Please read these guidelines before posting.

Join our Slack channel
======================

Slack has created a special slack server for the Selenium and Watir (including Nerodia) communities. You can join our Slack channel by sending Slack your email `here <http://seleniumhq.herokuapp.com/>`_. You will be sent an invitation with instructions on how to join.
